@@ -13,6 +13,7 @@ import Data.Time.Clock (UTCTime)
 import Data.Time.Clock.POSIX (posixSecondsToUTCTime)
 
 import Codec.Encryption.OpenPGP.Types
+import Codec.Encryption.OpenPGP.Ontology (isKET)
 
 -- this assumes that all key expiration time subpackets are valid
 isTKTimeValid :: UTCTime -> TK -> Bool
@@ -25,7 +26,3 @@ isTKTimeValid ct key = ct >= keyCreationTime && ct < keyExpirationTime
 
 getKeyExpirationTimesFromSignature :: SignaturePayload -> [ThirtyTwoBitDuration]
 getKeyExpirationTimesFromSignature (SigV4 _ _ _ xs _ _ _) = map (\(SigSubPacket _ (KeyExpirationTime x)) -> x) $ filter isKET xs
-    where
-        isKET (SigSubPacket _ (KeyExpirationTime _)) = True
-        isKET _ = False
-getKeyExpirationTimesFromSignature _ = []
