@@ -73,7 +73,7 @@ pubkeyToMPIs (DSAPubKey (DSA_PublicKey k)) = [
                              ]
   where pkParams f = MPI . f . DSA.public_params $ k
 
-pubkeyToMPIs (ElGamalPubKey k) = fmap MPI k
+pubkeyToMPIs (ElGamalPubKey p g y) = [MPI p, MPI g, MPI y]
 
 multiplicativeInverse :: Integral a => a -> a -> a
 multiplicativeInverse _ 1 = 1
