@@ -1,5 +1,5 @@
 -- KeyInfo.hs: OpenPGP (RFC4880) fingerprinting methods
--- Copyright © 2012-2015  Clint Adams
+-- Copyright © 2012-2016  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -10,19 +10,22 @@ module Codec.Encryption.OpenPGP.KeyInfo (
 
 import qualified Crypto.PubKey.RSA as RSA
 import qualified Crypto.PubKey.DSA as DSA
-import qualified Data.ByteString as B
 import Data.Bits (shiftR)
 import Data.List (unfoldr)
 
 import Codec.Encryption.OpenPGP.Types
 
+pubkeySize :: PKey -> Either String Int
 pubkeySize (RSAPubKey (RSA_PublicKey x)) = Right (RSA.public_size x * 8)
 pubkeySize (DSAPubKey (DSA_PublicKey x)) = Right (bitcount . DSA.params_p . DSA.public_params $ x)
-pubkeySize (ElGamalPubKey x) = Right (bitcount $ head x)
+pubkeySize (ElGamalPubKey p _ _) = Right (bitcount p)
 pubkeySize x = Left $ "Unable to calculate size of " ++ show x
 
+bitcount :: Integer -> Int
 bitcount = (*8) . length . unfoldr (\x -> if x == 0 then Nothing else Just (True, x `shiftR` 8))
 
+-- FIXME: redo these for hOpenPGP 3
+pkalgoAbbrev :: PubKeyAlgorithm -> String
 pkalgoAbbrev RSA = "R"
 pkalgoAbbrev DSA = "D"
 pkalgoAbbrev ElgamalEncryptOnly = "g"
