@@ -125,8 +125,8 @@ signature intolerant rts = if intolerant then signature' else signature' <|> bro
         signature' = do [SignaturePkt sp] <- satisfy (isSP intolerant)
                         return $! (if intolerant then id else filter isSP') [sp]
         brokensig' = const [] <$> broken 2
-        isSP True [SignaturePkt sp@(SigV3 {})] = isSP' sp
-        isSP True [SignaturePkt sp@(SigV4 {})] = isSP' sp
+        isSP True [SignaturePkt sp@SigV3{}] = isSP' sp
+        isSP True [SignaturePkt sp@SigV4{}] = isSP' sp
         isSP False [SignaturePkt _] = True
         isSP _ _ = False
         isSP' (SigV3 st _ _ _ _ _ _) = st `elem` rts
