@@ -32,10 +32,10 @@ saBlockSize :: SymmetricAlgorithm -> Int
 saBlockSize sa = either (const 0) id (withSymmetricCipher sa B.empty (Right . blockSize))
 
 decryptPrivateKey :: (PKPayload, SKAddendum) -> BL.ByteString -> SKAddendum
-decryptPrivateKey (pkp, ska@(SUS16bit {})) pp = either (error "could not decrypt SUS16bit") id (decryptSKA (pkp, ska) pp)
-decryptPrivateKey (pkp, ska@(SUSSHA1 {})) pp = either (error "could not decrypt SUSSHA1") id (decryptSKA (pkp, ska) pp)
-decryptPrivateKey (_, SUSym {}) _ = error "SUSym key decryption not implemented"
-decryptPrivateKey (_, ska@(SUUnencrypted {})) _ = ska
+decryptPrivateKey (pkp, ska@SUS16bit{}) pp = either (error "could not decrypt SUS16bit") id (decryptSKA (pkp, ska) pp)
+decryptPrivateKey (pkp, ska@SUSSHA1{}) pp = either (error "could not decrypt SUSSHA1") id (decryptSKA (pkp, ska) pp)
+decryptPrivateKey (_, SUSym{}) _ = error "SUSym key decryption not implemented"
+decryptPrivateKey (_, ska@SUUnencrypted{}) _ = ska
 
 decryptSKA :: (PKPayload, SKAddendum) -> BL.ByteString -> Either String SKAddendum
 decryptSKA (pkp, SUS16bit sa s2k iv payload) pp = do
@@ -67,9 +67,9 @@ encryptPrivateKeyIO ska pp = saltiv >>= \(s,i) -> return (encryptPrivateKey s (I
 
 -- |8-octet salt, IV must be length of cipher blocksize
 encryptPrivateKey :: B.ByteString -> IV -> SKAddendum -> BL.ByteString -> SKAddendum
-encryptPrivateKey _ _ ska@(SUS16bit {}) _ = ska
-encryptPrivateKey _ _ ska@(SUSSHA1 {}) _ = ska
-encryptPrivateKey _ _ ska@(SUSym {}) _ = ska
+encryptPrivateKey _ _ ska@SUS16bit{} _ = ska
+encryptPrivateKey _ _ ska@SUSSHA1{} _ = ska
+encryptPrivateKey _ _ ska@SUSym{} _ = ska
 encryptPrivateKey salt iv (SUUnencrypted skey _) pp = SUSSHA1 AES256 s2k iv (BL.fromStrict (encryptSKey skey s2k iv pp))
     where
        s2k = IteratedSalted SHA512 (Salt salt) 12058624
