@@ -18,7 +18,7 @@ import Control.Applicative ((<$>))
 #endif
 import Control.Applicative (many, some)
 import Control.Lens ((^.), _1)
-import Control.Monad (guard, liftM, replicateM, replicateM_)
+import Control.Monad (guard, replicateM, replicateM_)
 import Crypto.Number.Basic (numBits)
 import Crypto.Number.Serialize (i2osp, os2ip)
 import qualified Crypto.PubKey.RSA as R
@@ -56,19 +56,19 @@ instance Binary SigSubPacket where
 --     put = putNotationFlagSet
 
 instance Binary CompressionAlgorithm where
-    get = liftM toFVal getWord8
+    get = toFVal <$> getWord8
     put = putWord8 . fromFVal
 
 instance Binary PubKeyAlgorithm where
-    get = liftM toFVal getWord8
+    get = toFVal <$> getWord8
     put = putWord8 . fromFVal
 
 instance Binary HashAlgorithm where
-    get = liftM toFVal getWord8
+    get = toFVal <$> getWord8
     put = putWord8 . fromFVal
 
 instance Binary SymmetricAlgorithm where
-    get = liftM toFVal getWord8
+    get = toFVal <$> getWord8
     put = putWord8 . fromFVal
 
 instance Binary MPI where
@@ -76,7 +76,7 @@ instance Binary MPI where
     put = putMPI
 
 instance Binary SigType where
-    get = liftM toFVal getWord8
+    get = toFVal <$> getWord8
     put = putWord8 . fromFVal
 
 instance Binary UserAttrSubPacket where
@@ -782,7 +782,7 @@ getPubkey ElgamalEncryptOnly = getPubkey ForbiddenElgamal
 getPubkey ForbiddenElgamal = do MPI p <- get
                                 MPI g <- get
                                 MPI y <- get
-                                return $ ElGamalPubKey [p,g,y]
+                                return $ ElGamalPubKey p g y
 getPubkey _ = UnknownPKey <$> getRemainingLazyByteString
 
 putPubkey :: PKey -> Put
@@ -805,7 +805,7 @@ getSecretKey pkp
                               return $ DSAPrivateKey (DSA_PrivateKey (D.PrivateKey (D.Params 0 0 0) x))
     | _pkalgo pkp `elem` [ElgamalEncryptOnly,ForbiddenElgamal] =
         do MPI x <- get
-           return $ ElGamalPrivateKey [x]
+           return $ ElGamalPrivateKey x
 
 putSKey :: SKey -> Put
 putSKey (RSAPrivateKey (RSA_PrivateKey (R.PrivateKey _ d p q _ _ _))) = put (MPI d) >> put (MPI p) >> put (MPI q) >> put (MPI u)
