@@ -154,5 +154,5 @@ finalPayload s pl = BL.concat [pl, sigbit, trailer s]
     where
         sigbit = runPut $ putPartialSigforSigning s
         trailer :: Pkt -> ByteString
-        trailer (SignaturePkt (SigV4 {})) = runPut $ putSigTrailer s
+        trailer (SignaturePkt SigV4{}) = runPut $ putSigTrailer s
         trailer _ = BL.empty
