@@ -31,7 +31,9 @@ import Data.Byteable (Byteable)
 import Data.ByteArray (ByteArrayAccess)
 import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString as B
+import qualified Data.ByteString.Base16.Lazy as B16L
 import qualified Data.ByteString.Lazy as BL
+import qualified Data.ByteString.Lazy.Char8 as BLC8
 import Data.Char (toLower, toUpper)
 import Data.Data (Data)
 import Data.Hashable (Hashable(..))
@@ -54,7 +56,7 @@ import Data.Time.Format (formatTime)
 import Data.Typeable (Typeable)
 import Data.Word (Word8, Word16, Word32)
 import Network.URI (URI(..), uriToString, nullURI, parseURI)
-import Numeric (readHex, showHex)
+import Numeric (readHex)
 import Data.Time.Locale.Compat (defaultTimeLocale)
 import Text.PrettyPrint.Free (Pretty(..), (<+>), char, hsep, punctuate, space, text)
 
@@ -153,7 +155,7 @@ instance Pretty SymmetricAlgorithm where
     pretty Camellia128 = text "Camellia-128"
     pretty Camellia192 = text "Camellia-192"
     pretty Camellia256 = text "Camellia-256"
-    pretty (OtherSA sa) = text "unknown symmetric algorithm" <+> (text . show) sa
+    pretty (OtherSA sa) = text "unknown symmetric algorithm" <+> pretty sa
 
 $(ATH.deriveJSON ATH.defaultOptions ''SymmetricAlgorithm)
 
@@ -291,7 +293,7 @@ instance Pretty PubKeyAlgorithm where
     pretty ECDSA = text "ECDSA"
     pretty ForbiddenElgamal = text "(forbidden) Elgamal"
     pretty DH = text "DH"
-    pretty pka = text "unknown pubkey algorithm type" <+> (text . show) pka
+    pretty (OtherPKA pka) = text "unknown pubkey algorithm type" <+> pretty pka
 
 $(ATH.deriveJSON ATH.defaultOptions ''PubKeyAlgorithm)
 
@@ -309,7 +311,7 @@ instance Read TwentyOctetFingerprint where
 instance Hashable TwentyOctetFingerprint
 
 instance Pretty TwentyOctetFingerprint where
-    pretty = text . take 40 . w8sToHex . BL.unpack . unTOF
+    pretty = pretty . take 40 . bsToHexUpper . unTOF
 
 instance A.ToJSON TwentyOctetFingerprint where
     toJSON e = object [T.pack "fpr" .= (A.toJSON . show . pretty) e]
@@ -325,10 +327,10 @@ instance Newtype SpacedFingerprint TwentyOctetFingerprint where
     unpack (SpacedFingerprint o) = o
 
 instance Pretty SpacedFingerprint where
-    pretty = hsep . punctuate space . map hsep . chunksOf 5 . map text . chunksOf 4 . take 40 . w8sToHex . BL.unpack . unTOF . unpack
+    pretty = hsep . punctuate space . map hsep . chunksOf 5 . map text . chunksOf 4 . take 40 . bsToHexUpper . unTOF . unpack
 
-w8sToHex :: [Word8] -> String
-w8sToHex = map toUpper . concatMap ((\x -> if length x == 1 then '0':x else x) . flip showHex "")
+bsToHexUpper :: ByteString -> String
+bsToHexUpper = map toUpper . BLC8.unpack . B16L.encode
 
 hexToW8s :: ReadS Word8
 hexToW8s = concatMap readHex . chunksOf 2 . map toLower
@@ -341,7 +343,7 @@ instance Newtype EightOctetKeyId ByteString where
     unpack (EightOctetKeyId o) = o
 
 instance Pretty EightOctetKeyId where
-    pretty = text . w8sToHex . BL.unpack . unpack
+    pretty = pretty . bsToHexUpper . unpack
 
 -- FIXME: read-show
 instance Read EightOctetKeyId where
@@ -350,7 +352,7 @@ instance Read EightOctetKeyId where
 instance Hashable EightOctetKeyId
 
 instance A.ToJSON EightOctetKeyId where
-    toJSON e = object [T.pack "eoki" .= (w8sToHex . BL.unpack . unpack) e]
+    toJSON e = object [T.pack "eoki" .= (bsToHexUpper . unpack) e]
 
 instance A.FromJSON EightOctetKeyId where
     parseJSON (A.Object v) = EightOctetKeyId . read <$>
@@ -429,7 +431,7 @@ instance Pretty HashAlgorithm where
     pretty SHA384 = text "SHA-384"
     pretty SHA512 = text "SHA-512"
     pretty SHA224 = text "SHA-224"
-    pretty (OtherHA ha) = text "unknown hash algorithm type" <+> (text . show) ha
+    pretty (OtherHA ha) = text "unknown hash algorithm type" <+> pretty ha
 
 $(ATH.deriveJSON ATH.defaultOptions ''HashAlgorithm)
 
@@ -465,7 +467,7 @@ instance Pretty CompressionAlgorithm where
     pretty ZIP = text "ZIP"
     pretty ZLIB = text "zlib"
     pretty BZip2 = text "bzip2"
-    pretty (OtherCA ca) = text "unknown compression algorithm type" <+> (text . show) ca
+    pretty (OtherCA ca) = text "unknown compression algorithm type" <+> pretty ca
 
 $(ATH.deriveJSON ATH.defaultOptions ''CompressionAlgorithm)
 
@@ -733,8 +735,8 @@ data SignaturePayload = SigV3 SigType ThirtyTwoBitTimeStamp EightOctetKeyId PubK
 instance Hashable SignaturePayload
 
 instance Pretty SignaturePayload where
-    pretty (SigV3 st ts eoki pka ha w16 mpis) = text "signature v3" <> char ':' <+> pretty st <+> pretty ts <+> pretty eoki <+> pretty pka <+> pretty ha <+> pretty w16 <+> (prettyList . NE.toList) mpis
-    pretty (SigV4 st pka ha hsps usps w16 mpis) = text "signature v4" <> char ':' <+> pretty st <+> pretty pka <+> pretty ha <+> prettyList hsps <+> prettyList usps <+> pretty w16 <+> (prettyList . NE.toList) mpis
+    pretty (SigV3 st ts eoki pka ha w16 mpis) = text "signature v3" <> char ':' <+> pretty st <+> pretty ts <+> pretty eoki <+> pretty pka <+> pretty ha <+> pretty w16 <+> (pretty . NE.toList) mpis
+    pretty (SigV4 st pka ha hsps usps w16 mpis) = text "signature v4" <> char ':' <+> pretty st <+> pretty pka <+> pretty ha <+> pretty hsps <+> pretty usps <+> pretty w16 <+> (pretty . NE.toList) mpis
     pretty (SigVOther t bs) = text "unknown signature v" <> pretty t <> char ':' <+> pretty (BL.unpack bs)
 
 instance A.ToJSON SignaturePayload where
@@ -779,20 +781,20 @@ instance Pretty SigSubPacketPayload where
     pretty (RegularExpression apdre) = text "regular expression" <+> pretty apdre
     pretty (Revocable r) = text "revocable" <+> pretty r
     pretty (KeyExpirationTime d) = text "key expiration time" <+> pretty d
-    pretty (PreferredSymmetricAlgorithms sas) = text "preferred symmetric algorithms" <+> prettyList sas
-    pretty (RevocationKey rcs pka tof) = text "revocation key" <+> prettyList (Set.toList rcs) <+> pretty pka <+> pretty tof
+    pretty (PreferredSymmetricAlgorithms sas) = text "preferred symmetric algorithms" <+> pretty sas
+    pretty (RevocationKey rcs pka tof) = text "revocation key" <+> pretty (Set.toList rcs) <+> pretty pka <+> pretty tof
     pretty (Issuer eoki) = text "issuer" <+> pretty eoki
-    pretty (NotationData nfs nn nv) = text "notation data" <+> prettyList (Set.toList nfs) <+> pretty nn <+> pretty nv
-    pretty (PreferredHashAlgorithms phas) = text "preferred hash algorithms" <+> prettyList phas
+    pretty (NotationData nfs nn nv) = text "notation data" <+> pretty (Set.toList nfs) <+> pretty nn <+> pretty nv
+    pretty (PreferredHashAlgorithms phas) = text "preferred hash algorithms" <+> pretty phas
     pretty (PreferredCompressionAlgorithms pcas) = text "preferred compression algorithms" <+> pretty pcas
-    pretty (KeyServerPreferences kspfs) = text "keyserver preferences" <+> prettyList (Set.toList kspfs)
+    pretty (KeyServerPreferences kspfs) = text "keyserver preferences" <+> pretty (Set.toList kspfs)
     pretty (PreferredKeyServer ks) = text "preferred keyserver" <+> pretty ks
     pretty (PrimaryUserId p) = (if p then mempty else text "NOT ") <> text "primary user-ID"
     pretty (PolicyURL u) = text "policy URL" <+> pretty u
-    pretty (KeyFlags kfs) = text "key flags" <+> prettyList (Set.toList kfs)
+    pretty (KeyFlags kfs) = text "key flags" <+> pretty (Set.toList kfs)
     pretty (SignersUserId u) = text "signer's user-ID" <+> pretty u
     pretty (ReasonForRevocation rc rr) = text "reason for revocation" <+> pretty rc <+> pretty rr
-    pretty (Features ffs) = text "features" <+> prettyList (Set.toList ffs)
+    pretty (Features ffs) = text "features" <+> pretty (Set.toList ffs)
     pretty (SignatureTarget pka ha sh) = text "signature target" <+> pretty pka <+> pretty ha <+> pretty sh
     pretty (EmbeddedSignature sp) = text "embedded signature" <+> pretty sp
     pretty (UserDefinedSigSub t bs) = text "user-defined signature subpacket type" <+> pretty t <+> pretty (BL.unpack bs)
@@ -874,7 +876,7 @@ instance Newtype IV B.ByteString where
     unpack (IV o) = o
 
 instance Pretty IV where
-    pretty = pretty . unpack
+    pretty = pretty . ("iv:"++) . bsToHexUpper . BL.fromStrict . unpack
 
 instance A.ToJSON IV where
     toJSON = A.toJSON . show . unpack
@@ -908,7 +910,7 @@ instance Pretty DataType where
     pretty BinaryData = text "binary"
     pretty TextData = text "text"
     pretty UTF8Data = text "UTF-8"
-    pretty (OtherData o) = text "other data type " <+> (text . show) o
+    pretty (OtherData o) = text "other data type " <+> pretty o
 
 $(ATH.deriveJSON ATH.defaultOptions ''DataType)
 
@@ -920,7 +922,7 @@ instance Newtype Salt B.ByteString where
     unpack (Salt o) = o
 
 instance Pretty Salt where
-    pretty = pretty . unpack
+    pretty = pretty . ("salt:"++) . bsToHexUpper . BL.fromStrict . unpack
 
 instance A.ToJSON Salt where
     toJSON = A.toJSON . show . unpack
@@ -947,9 +949,9 @@ instance Hashable S2K
 
 instance Pretty S2K where
     pretty (Simple ha) = text "simple S2K," <+> pretty ha
-    pretty (Salted ha salt) = text "simple S2K," <+> pretty ha <+> pretty salt
-    pretty (IteratedSalted ha salt icount) = text "simple S2K," <+> pretty ha <+> pretty salt <+> pretty icount
-    pretty (OtherS2K t bs) = text "unknown S2K type" <+> pretty t <+> pretty bs
+    pretty (Salted ha salt) = text "salted S2K," <+> pretty ha <+> pretty salt
+    pretty (IteratedSalted ha salt icount) = text "iterated-salted S2K," <+> pretty ha <+> pretty salt <+> pretty icount
+    pretty (OtherS2K t bs) = text "unknown S2K type" <+> pretty t <+> pretty (bsToHexUpper bs)
 
 instance A.ToJSON S2K where
     toJSON (Simple ha) = A.toJSON ha
@@ -1009,7 +1011,7 @@ instance Ord UserAttrSubPacket where
 
 instance Pretty UserAttrSubPacket where
     pretty (ImageAttribute ih d) = text "image-attribute" <+> pretty ih <+> pretty (BL.unpack d)
-    pretty (OtherUASub t bs) = text "unknown attribute type" <> (text . show) t <+> pretty (BL.unpack bs)
+    pretty (OtherUASub t bs) = text "unknown attribute type" <> pretty t <+> pretty (BL.unpack bs)
 
 instance A.ToJSON UserAttrSubPacket where
     toJSON (ImageAttribute ih d) = A.toJSON (ih, BL.unpack d)
