@@ -30,7 +30,7 @@ import Text.PrettyPrint.Free (Pretty(..), (<+>), text)
 
 data PKey = RSAPubKey RSA_PublicKey
           | DSAPubKey DSA_PublicKey
-          | ElGamalPubKey [Integer]
+          | ElGamalPubKey Integer Integer Integer
           | ECDHPubKey ECDSA_PublicKey HashAlgorithm SymmetricAlgorithm
           | ECDSAPubKey ECDSA_PublicKey
           | UnknownPKey ByteString
@@ -41,22 +41,22 @@ instance Hashable PKey
 instance Pretty PKey where
     pretty (RSAPubKey p) = text "RSA" <+> pretty p
     pretty (DSAPubKey p) = text "DSA" <+> pretty p
-    pretty (ElGamalPubKey p) = text "Elgamal" <+> pretty p
+    pretty (ElGamalPubKey p g y) = text "Elgamal" <+> pretty p <+> pretty g <+> pretty y
     pretty (ECDHPubKey p ha sa) = text "ECDH" <+> pretty p <+> pretty ha <+> pretty sa
     pretty (ECDSAPubKey p) = text "ECDSA" <+> pretty p
-    pretty (UnknownPKey bs) = text "unknown" <+> pretty bs
+    pretty (UnknownPKey bs) = text "<unknown>" <+> pretty (bsToHexUpper bs)
 
 instance A.ToJSON PKey where
     toJSON (RSAPubKey p) = A.toJSON p
     toJSON (DSAPubKey p) = A.toJSON p
-    toJSON (ElGamalPubKey p) = A.toJSON p
+    toJSON (ElGamalPubKey p g y) = A.toJSON (p, g, y)
     toJSON (ECDHPubKey p ha sa) = A.toJSON (p, ha, sa)
     toJSON (ECDSAPubKey p) = A.toJSON p
     toJSON (UnknownPKey bs) = A.toJSON (BL.unpack bs)
 
 data SKey = RSAPrivateKey RSA_PrivateKey
           | DSAPrivateKey DSA_PrivateKey
-          | ElGamalPrivateKey [Integer]
+          | ElGamalPrivateKey Integer
           | ECDHPrivateKey ECDSA_PrivateKey
           | ECDSAPrivateKey ECDSA_PrivateKey
           | UnknownSKey ByteString
@@ -70,7 +70,7 @@ instance Pretty SKey where
     pretty (ElGamalPrivateKey p) = text "Elgamal" <+> pretty p
     pretty (ECDHPrivateKey p) = text "ECDH" <+> pretty p
     pretty (ECDSAPrivateKey p) = text "ECDSA" <+> pretty p
-    pretty (UnknownSKey bs) = text "unknown" <+> pretty bs
+    pretty (UnknownSKey bs) = text "<unknown>" <+> pretty (bsToHexUpper bs)
 
 instance A.ToJSON SKey where
     toJSON (RSAPrivateKey k) = A.toJSON k
@@ -110,9 +110,9 @@ instance Ord SKAddendum where
 instance Hashable SKAddendum
 
 instance Pretty SKAddendum where
-    pretty (SUS16bit sa s2k iv bs) = text "SUS16bit" <+> pretty sa <+> pretty s2k <+> pretty iv <+> pretty bs
-    pretty (SUSSHA1 sa s2k iv bs) = text "SUSSHA1" <+> pretty sa <+> pretty s2k <+> pretty iv <+> pretty bs
-    pretty (SUSym sa iv bs) = text "SUSym" <+> pretty sa <+> pretty iv <+> pretty bs
+    pretty (SUS16bit sa s2k iv bs) = text "SUS16bit" <+> pretty sa <+> pretty s2k <+> pretty iv <+> pretty (bsToHexUpper bs)
+    pretty (SUSSHA1 sa s2k iv bs) = text "SUSSHA1" <+> pretty sa <+> pretty s2k <+> pretty iv <+> pretty (bsToHexUpper bs)
+    pretty (SUSym sa iv bs) = text "SUSym" <+> pretty sa <+> pretty iv <+> pretty (bsToHexUpper bs)
     pretty (SUUnencrypted s ck) = text "SUUnencrypted" <+> pretty s <+> pretty ck
 
 instance A.ToJSON SKAddendum where
