@@ -67,25 +67,25 @@ instance Ord Pkt where
     compare = comparing pktTag <> comparing hash -- FIXME: is there something saner?
 
 instance Pretty Pkt where
-    pretty (PKESKPkt pv eoki pka mpis) = text "PKESK v" <> (text . show) pv <> char ':' <+> pretty eoki <+> pretty pka <+> (prettyList . NE.toList) mpis
+    pretty (PKESKPkt pv eoki pka mpis) = text "PKESK v" <> pretty pv <> char ':' <+> pretty eoki <+> pretty pka <+> (pretty . NE.toList) mpis
     pretty (SignaturePkt sp) = pretty sp
-    pretty (SKESKPkt pv sa s2k mbs) = text "SKESK v" <> (text . show) pv <> char ':' <+> pretty sa <+> pretty s2k <+> pretty mbs
-    pretty (OnePassSignaturePkt pv st ha pka eoki nestedflag) = text "one-pass signature v" <> (text . show) pv <> char ':' <+> pretty st <+> pretty ha <+> pretty pka <+> pretty eoki <+> pretty nestedflag
+    pretty (SKESKPkt pv sa s2k mbs) = text "SKESK v" <> pretty pv <> char ':' <+> pretty sa <+> pretty s2k <+> pretty (fmap bsToHexUpper mbs)
+    pretty (OnePassSignaturePkt pv st ha pka eoki nestedflag) = text "one-pass signature v" <> pretty pv <> char ':' <+> pretty st <+> pretty ha <+> pretty pka <+> pretty eoki <+> pretty nestedflag
     pretty (SecretKeyPkt pkp ska) = text "secret key:" <+> pretty pkp <+> pretty ska
     pretty (PublicKeyPkt pkp) = text "public key:" <+> pretty pkp
     pretty (SecretSubkeyPkt pkp ska) = text "secret subkey:" <+> pretty pkp <+> pretty ska
     pretty (CompressedDataPkt ca cdp) = text "compressed-data:" <+> pretty ca <+> pretty cdp
-    pretty (SymEncDataPkt bs) = text "symmetrically-encrypted-data:" <+> pretty bs
-    pretty (MarkerPkt bs) = text "marker:" <+> pretty bs
-    pretty (LiteralDataPkt dt fn ts bs) = text "literal-data" <+> pretty dt <+> pretty fn <+> pretty ts <+> pretty bs
+    pretty (SymEncDataPkt bs) = text "symmetrically-encrypted-data:" <+> pretty (bsToHexUpper bs)
+    pretty (MarkerPkt bs) = text "marker:" <+> pretty (bsToHexUpper bs)
+    pretty (LiteralDataPkt dt fn ts bs) = text "literal-data" <+> pretty dt <+> pretty fn <+> pretty ts <+> pretty (bsToHexUpper bs)
     pretty (TrustPkt bs) = text "trust:" <+> pretty (BL.unpack bs)
     pretty (UserIdPkt u) = text "user-ID:" <+> pretty u
     pretty (PublicSubkeyPkt pkp) = text "public subkey:" <+> pretty pkp
-    pretty (UserAttributePkt us) = text "user-attribute:" <+> prettyList us
-    pretty (SymEncIntegrityProtectedDataPkt pv bs) = text "symmetrically-encrypted-integrity-protected-data v" <> (text . show) pv <> char ':' <+> pretty bs
-    pretty (ModificationDetectionCodePkt bs) = text "MDC:" <+> pretty bs
-    pretty (OtherPacketPkt t bs) = text "unknown packet type" <+> pretty t <> char ':' <+> pretty bs
-    pretty (BrokenPacketPkt s t bs) = text "BROKEN packet (" <> pretty s <> char ')' <+> pretty t <> char ':' <+> pretty bs
+    pretty (UserAttributePkt us) = text "user-attribute:" <+> pretty us
+    pretty (SymEncIntegrityProtectedDataPkt pv bs) = text "symmetrically-encrypted-integrity-protected-data v" <> pretty pv <> char ':' <+> pretty (bsToHexUpper bs)
+    pretty (ModificationDetectionCodePkt bs) = text "MDC:" <+> pretty (bsToHexUpper bs)
+    pretty (OtherPacketPkt t bs) = text "unknown packet type" <+> pretty t <> char ':' <+> pretty (bsToHexUpper bs)
+    pretty (BrokenPacketPkt s t bs) = text "BROKEN packet (" <> pretty s <> char ')' <+> pretty t <> char ':' <+> pretty (bsToHexUpper bs)
 
 instance A.ToJSON Pkt where
     toJSON (PKESKPkt pv eoki pka mpis) = object [T.pack "pkesk" .= object [T.pack "version" .= pv, T.pack "keyid" .= eoki, T.pack "pkalgo" .= pka, T.pack "mpis" .= NE.toList mpis]]
@@ -109,22 +109,22 @@ instance A.ToJSON Pkt where
     toJSON (BrokenPacketPkt s t bs) = object [T.pack "brokenpacket" .= object [T.pack "error" .= s, T.pack "tag" .= t, T.pack "data" .= BL.unpack bs]]
 
 pktTag :: Pkt -> Word8
-pktTag (PKESKPkt {}) = 1
+pktTag PKESKPkt{} = 1
 pktTag (SignaturePkt _) = 2
-pktTag (SKESKPkt {}) = 3
-pktTag (OnePassSignaturePkt {}) = 4
-pktTag (SecretKeyPkt {}) = 5
+pktTag SKESKPkt{} = 3
+pktTag OnePassSignaturePkt{} = 4
+pktTag SecretKeyPkt{} = 5
 pktTag (PublicKeyPkt _) = 6
-pktTag (SecretSubkeyPkt {}) = 7
-pktTag (CompressedDataPkt {}) = 8
+pktTag SecretSubkeyPkt{} = 7
+pktTag CompressedDataPkt{} = 8
 pktTag (SymEncDataPkt _) = 9
 pktTag (MarkerPkt _) = 10
-pktTag (LiteralDataPkt {}) = 11
+pktTag LiteralDataPkt{} = 11
 pktTag (TrustPkt _) = 12
 pktTag (UserIdPkt _) = 13
 pktTag (PublicSubkeyPkt _) = 14
 pktTag (UserAttributePkt _) = 17
-pktTag (SymEncIntegrityProtectedDataPkt {}) = 18
+pktTag SymEncIntegrityProtectedDataPkt{} = 18
 pktTag (ModificationDetectionCodePkt _) = 19
 pktTag (OtherPacketPkt t _) = t
 pktTag (BrokenPacketPkt _ t _) = t -- is this the right thing to do?
