@@ -18,6 +18,7 @@ import Codec.Encryption.OpenPGP.Types.Internal.Pkt
 
 import Control.Lens (makeLenses)
 import qualified Data.Aeson as A
+import qualified Data.Aeson.TH as ATH
 import Data.Data (Data)
 import Data.IxSet.Typed (IxSet)
 import Data.Ord (comparing)
@@ -35,7 +36,7 @@ data TK = TK {
 instance Ord TK where
     compare = comparing _tkKey -- FIXME: is this ridiculous?
 
-instance A.ToJSON TK
+$(ATH.deriveToJSON ATH.defaultOptions ''TK)
 
 type KeyringIxs = '[EightOctetKeyId, TwentyOctetFingerprint, Text]
 type Keyring = IxSet KeyringIxs TK
