@@ -52,7 +52,7 @@ conduitDecrypt' depth cb = CL.concatMapAccumM push def { _depth = depth }  -- FI
         push i s
             | _depth s > 42 = fail "I think we've been quine-attacked"
             | otherwise = case i of
-                       (SKESKPkt {}) -> return (s { _lastSKESK = Just (fromPkt i) }, [])
+                       SKESKPkt{} -> return (s { _lastSKESK = Just (fromPkt i) }, [])
                        (SymEncDataPkt bs) -> do d <- decryptSEDP (_depth s) cb (fromJust . _lastSKESK $ s) bs
                                                 return (processLDPs s d, d)
                        (SymEncIntegrityProtectedDataPkt _ bs) -> do d <- decryptSEIPDP (_depth s) cb (fromJust . _lastSKESK $ s) bs
@@ -62,7 +62,7 @@ conduitDecrypt' depth cb = CL.concatMapAccumM push def { _depth = depth }  -- FI
                                                                   return (s, [m])
                        p -> return (s, [p])
         processLDPs s ds = S.execState (mapM_ ldpCheck ds) s
-        ldpCheck l@(LiteralDataPkt {}) = S.get >>= \o -> S.put o { _lastLDP = Just . fromPkt $ l }
+        ldpCheck l@LiteralDataPkt{} = S.get >>= \o -> S.put o { _lastLDP = Just . fromPkt $ l }
         ldpCheck _ = return ()
 
 decryptSEDP :: (MonadBaseControl IO m, MonadIO m, MonadThrow m) => Int -> InputCallback IO -> SKESK -> BL.ByteString -> m [Pkt]
