@@ -1,5 +1,5 @@
 -- Keyring.hs: OpenPGP (RFC4880) transferable keys parsing
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2016  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -32,11 +32,11 @@ fakecmAccum finalizer f =
     loop
   where
     loop accum =
-        await >>= maybe (Prelude.mapM_ yield (snd (finalizer accum))) go
+        await >>= maybe (mapM_ yield (snd (finalizer accum))) go
       where
         go a = do
             let (accum', bs) = f a accum
-            Prelude.mapM_ yield bs
+            mapM_ yield bs
             loop accum'
 
 conduitToTKs' :: Monad m => Bool -> Conduit Pkt m TK
