@@ -21,10 +21,10 @@ import qualified Data.Conduit.List as CL
 
 main :: IO ()
 main = defaultMain [
-  bgroup "keyring" [ bench "load keys"  $ whnfIO (loadKeys "tests/data/debian-keyring.gpg")
-                   , bench "load keyring"  $ whnfIO (loadKeyring "tests/data/debian-keyring.gpg")
-                   , bench "self-verify keys" $ whnfIO (selfVerifyKeys "tests/data/debian-keyring.gpg")
-                   , bench "self-verify keyring" $ whnfIO (selfVerifyKeyring "tests/data/debian-keyring.gpg")
+  bgroup "keyring" [ bench "load keys"  $ whnfIO (loadKeys "tests/data/pubring.gpg")
+                   , bench "load keyring"  $ whnfIO (loadKeyring "tests/data/pubring.gpg")
+                   , bench "self-verify keys" $ whnfIO (selfVerifyKeys "tests/data/pubring.gpg")
+                   , bench "self-verify keyring" $ whnfIO (selfVerifyKeyring "tests/data/pubring.gpg")
                    ]
                ]
   where
