@@ -16,6 +16,7 @@ import Codec.Encryption.OpenPGP.Arbitrary ()
 import Codec.Encryption.OpenPGP.Compression (decompressPkt, compressPkts)
 import Codec.Encryption.OpenPGP.Expirations (isTKTimeValid)
 import Codec.Encryption.OpenPGP.Fingerprint (eightOctetKeyID, fingerprint)
+import Codec.Encryption.OpenPGP.KeyInfo (pkalgoAbbrev, pubkeySize)
 import Codec.Encryption.OpenPGP.KeyringParser (parseTKs)
 import Codec.Encryption.OpenPGP.KeySelection (parseFingerprint)
 import Codec.Encryption.OpenPGP.SecretKey (decryptPrivateKey, encryptPrivateKey)
@@ -24,7 +25,7 @@ import Codec.Encryption.OpenPGP.Signatures (verifyTKWith, verifySigWith, verifyA
 import Codec.Encryption.OpenPGP.Types
 import Control.Error.Util (isRight)
 import Control.Monad.Trans.Resource (ResourceT, runResourceT)
-import Crypto.PubKey.RSA (PrivateKey(private_pub))
+import qualified Crypto.PubKey.RSA as RSA
 import Data.Conduit.Serialization.Binary (conduitGet)
 import Data.Conduit.OpenPGP.Compression (conduitCompress, conduitDecompress)
 import Data.Conduit.OpenPGP.Decrypt (conduitDecrypt)
@@ -83,14 +84,15 @@ testConduitOutputLength fpr c target = do
     len <- runResourceT $ CB.sourceFile ("tests/data/" ++ fpr) DC.$= c DC.$$ counter
     assertEqual ("expected length " ++ show target) target len
 
-testKeyIDandFingerprint :: FilePath -> String -> Assertion
-testKeyIDandFingerprint fpr kf = do
+testPKAandSizeAndKeyIDandFingerprint :: FilePath -> String -> Assertion
+testPKAandSizeAndKeyIDandFingerprint fpr kf = do
     bs <- BL.readFile $ "tests/data/" ++ fpr
     case runGet (get :: Get Pkt) bs of
         Left _ -> assertFailure $ "Decoding of " ++ fpr ++ " broke."
         Right (PublicKeyPkt pkp) -> do
-                                       assertEqual ("for " ++ fpr ++ " (spaceless)") (spaceless kf) (either (const "unknown") (show . pretty) (eightOctetKeyID pkp) ++ "/" ++ show (pretty (fingerprint pkp)))
-                                       assertEqual ("for " ++ fpr ++ " (spaced)") kf (either (const "unknown") (show . pretty) (eightOctetKeyID pkp) ++ "/" ++ show (pretty (SpacedFingerprint (fingerprint pkp))))
+                                       let pref = concat [pkalgoAbbrev (_pkalgo pkp), either (const "unknown") show (pubkeySize (_pubkey pkp)), ":", either (const "unknown") (show . pretty) (eightOctetKeyID pkp), "/"]
+                                       assertEqual ("for " ++ fpr ++ " (spaceless)") (spaceless kf) (pref ++ show (pretty (fingerprint pkp)))
+                                       assertEqual ("for " ++ fpr ++ " (spaced)") kf (pref ++ show (pretty (SpacedFingerprint (fingerprint pkp))))
         _ -> assertFailure "Expected public key, got something else."
     where
         spaceless = filter (/=' ')
@@ -148,9 +150,8 @@ testSecretKeyDecryption keyfile passfile = do
   passphrase <- BL.readFile $ "tests/data/" ++ passfile
   kr <- runResourceT $ CB.sourceFile ("tests/data/" ++ keyfile) DC.$= conduitGet get DC.$$ CL.consume
   let SecretKey pkp ska = fromPkt . head $ kr
-      SUUnencrypted (RSAPrivateKey (RSA_PrivateKey dpk)) _ = decryptPrivateKey (pkp, ska) passphrase  -- FIXME: better API for multiple keytypes
-      RSAPubKey (RSA_PublicKey pk) = _pubkey pkp
-  assertEqual "private key matches public key" pk (private_pub dpk)
+      SUUnencrypted skey _ = decryptPrivateKey (pkp, ska) passphrase
+  doPkeyAndSkeyMatch (_pubkey pkp) skey
 
 -- FIXME: this should be reworked either with tasty-golden or some other form of sanity
 testSecretKeyEncryption :: FilePath -> FilePath -> Assertion
@@ -167,7 +168,7 @@ testParsePktsUtil :: FilePath -> Assertion
 testParsePktsUtil fn = do
     let fpath = "tests/data/" ++ fn
     cp <- runResourceT $ CB.sourceFile fpath DC.$= conduitGet get DC.$$ CL.consume
-    pp <- BL.readFile fpath >>= return . parsePkts
+    pp <- parsePkts `fmap` BL.readFile fpath
     assertEqual "parsePkts utility function gives same results as conduit pipeline" cp pp
 
 testParseTKsUtil :: FilePath -> Assertion
@@ -276,9 +277,9 @@ unitTests = testGroup "Unit Tests" [
    , testCase "gnu-dummy-s2k-101-secret-key.gpg" (testSerialization "gnu-dummy-s2k-101-secret-key.gpg")
    , testCase "anibal-ed25519.gpg" (testSerialization "anibal-ed25519.gpg")
    ],
-  testGroup "KeyID/fingerprint group" [
-     testCase "v3 key" (testKeyIDandFingerprint "v3.key" "C7261095/CBD9 F412 6807 E405 CC2D  2712 1DF5 E86E")
-   , testCase "v4 key" (testKeyIDandFingerprint "000001-006.public_key" "D4D54EA16F87040E/421F 28FE AAD2 22F8 56C8  FFD5 D4D5 4EA1 6F87 040E")
+  testGroup "PKA/Size/KeyID/fingerprint group" [
+     testCase "v3 key" (testPKAandSizeAndKeyIDandFingerprint "v3.key" "R1024:C7261095/CBD9 F412 6807 E405 CC2D  2712 1DF5 E86E")
+   , testCase "v4 key" (testPKAandSizeAndKeyIDandFingerprint "000001-006.public_key" "R1248:D4D54EA16F87040E/421F 28FE AAD2 22F8 56C8  FFD5 D4D5 4EA1 6F87 040E")
    ],
   testGroup "Keyring group" [
      testCase "pubring 7732CF988A63EA86" (testKeyringLookup "pubring.gpg" "7732CF988A63EA86" True)
@@ -287,7 +288,6 @@ unitTests = testGroup "Unit Tests" [
    , testCase "secring 7732CF988A63EA86" (testKeyringLookup "secring.gpg" "7732CF988A63EA86" True)
    , testCase "secring 123456789ABCDEF0" (testKeyringLookup "secring.gpg" "123456789ABCDEF0" False)
    , testCase "secsub AD992E9C24399832" (testKeyringLookup "secring.gpg" "AD992E9C24399832" True)
-   , testCase "d-k 94FA372B2DA8B985" (testKeyringLookup "debian-keyring.gpg" "0x94FA372B2DA8B985" False)
    -- FIXME: should count keys in rings
    ],
   testGroup "Message verification group" [
@@ -389,5 +389,9 @@ cgp = conduitGet (get :: Get Pkt)
 fp :: Text -> TwentyOctetFingerprint
 fp = either error id . parseFingerprint
 
+doPkeyAndSkeyMatch :: PKey -> SKey -> Assertion
+doPkeyAndSkeyMatch (RSAPubKey (RSA_PublicKey rpub)) (RSAPrivateKey (RSA_PrivateKey rpriv)) = assertEqual "RSA private key matches RSA public key" rpub (RSA.private_pub rpriv)
+doPkeyAndSkeyMatch _ _ = assertFailure "matching unimplemented"
+
 main :: IO ()
 main = defaultMain tests
